@@ -1164,12 +1164,10 @@ class install_install extends module
 
 			foreach ($sql_query as $sql)
 			{
-				//$sql = trim(str_replace('|', ';', $sql));
-				if (!$db->sql_query($sql))
-				{
-					$error = $db->sql_error();
-					$this->p_master->db_error($error['message'], $sql, __LINE__, __FILE__);
-				}
+				// Ignore errors when the functions or types already exist
+				// to allow installing phpBB twice in the same database with
+				// a different prefix
+				$db->sql_query($sql);
 			}
 			unset($sql_query);
 		}
@@ -1962,7 +1960,7 @@ class install_install extends module
 				'bot_ip'		=> (string) $bot_ary[1],
 			));
 
-			$result = $db->sql_query($sql);
+			$db->sql_query($sql);
 		}
 	}
 
@@ -2083,7 +2081,7 @@ class install_install extends module
 		return array(
 			'language'		=> basename(request_var('language', '')),
 			'dbms'			=> request_var('dbms', ''),
-			'dbhost'		=> request_var('dbhost', ''),
+			'dbhost'		=> request_var('dbhost', '', true),
 			'dbport'		=> request_var('dbport', ''),
 			'dbuser'		=> request_var('dbuser', ''),
 			'dbpasswd'		=> request_var('dbpasswd', '', true),
